==> krita-3.0.92.tar.gz: krita-3.0.92/plugins/dockers/specificcolorselector/specificcolorselector_dock.h <==

/*
 *  Copyright (c) 2008 Cyrille Berger <cberger@cberger.net>
 *
 *  This library is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation; version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef _SPECIFICCOLORSELECTOR_DOCK_H_
#define _SPECIFICCOLORSELECTOR_DOCK_H_

#include <QDockWidget>

#include <kis_types.h>
#include <kis_mainwindow_observer.h>

class KisViewManager;
class KisCanvas2;
class KisSpecificColorSelectorWidget;

class SpecificColorSelectorDock : public QDockWidget, public KisMainwindowObserver
{
    Q_OBJECT
public:
    SpecificColorSelectorDock();
    QString observerName() { return "SpecificColorSelectorDock"; }
    /// reimplemented from KoCanvasObserverBase/KisMainwindowObserver
    virtual void setCanvas(KoCanvasBase *canvas);
    virtual void unsetCanvas();
    virtual void setMainWindow(KisViewManager* kisview);

private:
    KisCanvas2 *m_canvas;
    KisViewManager *m_view;
    KisSpecificColorSelectorWidget* m_colorSelector;
};


#endif

==> krita_4.0.1+dfsg.orig.tar.gz: krita-4.0.1/plugins/dockers/specificcolorselector/specificcolorselector_dock.h <==

/*
 *  Copyright (c) 2008 Cyrille Berger <cberger@cberger.net>
 *
 *  This library is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation; version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef _SPECIFICCOLORSELECTOR_DOCK_H_
#define _SPECIFICCOLORSELECTOR_DOCK_H_

#include <QDockWidget>
#include <QPointer>

#include <kis_types.h>
#include <kis_mainwindow_observer.h>
#include <kis_canvas2.h>

class KisViewManager;
class KisSpecificColorSelectorWidget;

class SpecificColorSelectorDock : public QDockWidget, public KisMainwindowObserver
{
    Q_OBJECT
public:
    SpecificColorSelectorDock();
    QString observerName() override { return "SpecificColorSelectorDock"; }
    /// reimplemented from KoCanvasObserverBase/KisMainwindowObserver
    void setCanvas(KoCanvasBase *canvas) override;
    void unsetCanvas() override;
    void setMainWindow(KisViewManager* kisview) override;

private:
    QPointer<KisCanvas2> m_canvas;
    KisViewManager *m_view;
    KisSpecificColorSelectorWidget* m_colorSelector;
};


#endif
